Module input

Module input 

Structs

Cursor
A cursor over an input stream of characters. It keeps track of the current position in the stream. It has the ability to put characters back into the stream.

Traits

HasSpan

Type Aliases

Pos
Byte position into an input stream.
Span
Byte span into an input stream (first pos, one past last pos)